import React from 'react';
import type { KeyBinding } from '@codemirror/view';
import { placeholder as codemirrorPlaceholder, EditorView } from '@codemirror/view';
import type { Diagnostic } from '@codemirror/lint';
import type { CompletionSource } from '@codemirror/autocomplete';
import { Facet } from '@codemirror/state';
import { LanguageSupport, HighlightStyle } from '@codemirror/language';
import type { Action } from './action-button';
import type { EditorRef } from './types';
export type CodemirrorThemeType = 'light' | 'dark';
export declare const editorPalette: {
    readonly light: {
        readonly color: string;
        readonly backgroundColor: string;
        readonly disabledColor: string;
        readonly disabledBackgroundColor: string;
        readonly gutterColor: string;
        readonly gutterBackgroundColor: string;
        readonly gutterActiveLineBackgroundColor: string;
        readonly gutterFoldButtonColor: "#001E2B";
        readonly cursorColor: "#889397";
        readonly activeLineBackgroundColor: string;
        readonly selectionBackgroundColor: "#C3E7FE";
        readonly bracketBorderColor: "#C1C7C6";
        readonly infoGutterIconColor: string;
        readonly warningGutterIconColor: string;
        readonly errorGutterIconColor: string;
        readonly foldPlaceholderColor: "#889397";
        readonly foldPlaceholderBackgroundColor: "#F9FBFA";
        readonly autocompleteColor: "#001E2B";
        readonly autocompleteBackgroundColor: "#F9FBFA";
        readonly autocompleteBorderColor: "#E8EDEB";
        readonly autocompleteMatchColor: "#00A35C";
        readonly autocompleteSelectedBackgroundColor: "#E8EDEB";
    };
    readonly dark: {
        readonly color: string;
        readonly backgroundColor: string;
        readonly disabledColor: string;
        readonly disabledBackgroundColor: "#1C2D38";
        readonly gutterColor: string;
        readonly gutterBackgroundColor: string;
        readonly gutterActiveLineBackgroundColor: string;
        readonly gutterFoldButtonColor: "#FFFFFF";
        readonly cursorColor: "#00ED64";
        readonly activeLineBackgroundColor: string;
        readonly selectionBackgroundColor: "#3D4F58";
        readonly bracketBorderColor: "#C1C7C6";
        readonly infoGutterIconColor: string;
        readonly warningGutterIconColor: string;
        readonly errorGutterIconColor: string;
        readonly foldPlaceholderColor: "#889397";
        readonly foldPlaceholderBackgroundColor: "#1C2D38";
        readonly autocompleteColor: "#C1C7C6";
        readonly autocompleteBackgroundColor: "#112733";
        readonly autocompleteBorderColor: "#5C6C75";
        readonly autocompleteMatchColor: "#F9FBFA";
        readonly autocompleteSelectedBackgroundColor: "#3D4F58";
    };
};
declare const highlightStyles: {
    readonly light: HighlightStyle;
    readonly dark: HighlightStyle;
};
type EditorLanguage = 'json' | 'javascript' | 'javascript-expression';
export type Annotation = Pick<Diagnostic, 'from' | 'to' | 'severity' | 'message'>;
type EditorProps = {
    language?: EditorLanguage;
    onChangeText?: (text: string, event?: any) => void;
    onLoad?: (editor: EditorView) => void;
    onFocus?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onBlur?: (editor: React.FocusEvent<HTMLDivElement>) => void;
    onPaste?: (editor: React.ClipboardEvent<HTMLDivElement>) => void;
    darkMode?: boolean;
    disabled?: boolean;
    showLineNumbers?: boolean;
    showFoldGutter?: boolean;
    showAnnotationsGutter?: boolean;
    showScroll?: boolean;
    highlightActiveLine?: boolean;
    readOnly?: boolean;
    'data-testid'?: string;
    annotations?: Annotation[];
    completer?: CompletionSource;
    minLines?: number;
    maxLines?: number;
    lineHeight?: number;
    placeholder?: Parameters<typeof codemirrorPlaceholder>[0];
    commands?: readonly KeyBinding[];
    initialJSONFoldAll?: boolean;
} & ({
    text: string;
    initialText?: never;
} | {
    text?: never;
    initialText: string;
}) & Pick<React.HTMLProps<HTMLDivElement>, 'id' | 'className' | 'onFocus' | 'onPaste' | 'onBlur'>;
export declare const languages: Record<EditorLanguage, () => LanguageSupport>;
export declare const languageName: Facet<EditorLanguage, readonly EditorLanguage[]>;
declare const BaseEditor: React.ForwardRefExoticComponent<EditorProps & React.RefAttributes<EditorRef>>;
export type { EditorView, KeyBinding as Command };
type InlineEditorProps = Omit<EditorProps, 'text' | 'showLineNumbers' | 'showFoldGutter' | 'showAnnotationsGutter' | 'showScroll' | 'highlightActiveLine' | 'minLines' | 'annotations'> & ({
    text: string;
    initialText?: never;
} | {
    text?: never;
    initialText: string;
});
declare const InlineEditor: React.ForwardRefExoticComponent<InlineEditorProps & React.RefAttributes<EditorRef>>;
type MultilineEditorProps = EditorProps & {
    customActions?: Action[];
    copyable?: boolean;
    formattable?: boolean;
    editorClassName?: string;
    actionsClassName?: string;
    onExpand?: () => void;
    expanded?: boolean;
};
declare const MultilineEditor: React.ForwardRefExoticComponent<MultilineEditorProps & React.RefAttributes<EditorRef>>;
/**
 * Sets the editor value, use this with RTL like this:
 *
 * ```
 * render(<Editor data-testid='my-editor' />);
 * setCodemirrorEditorValue(screen.getByTestId('editor-test-id'), 'my text');
 * ```
 */
declare function setCodemirrorEditorValue(element: Element | string | null, text: string): Promise<void>;
/**
 * Retrieves the contents of an editor, use this with RTL like this:
 *
 * ```
 * render(<Editor data-testid='my-editor' />);
 * getCodemirrorEditorValue(screen.getByTestId('editor-test-id'));
 * ```
 */
declare function getCodemirrorEditorValue(element: Element | string | null): string;
export { BaseEditor };
export { InlineEditor as CodemirrorInlineEditor };
export { MultilineEditor as CodemirrorMultilineEditor };
export { setCodemirrorEditorValue };
export { getCodemirrorEditorValue };
export type { CompletionSource as Completer };
export { highlightStyles };
//# sourceMappingURL=editor.d.ts.map